@@ -104,7 +104,7 @@ def get_attrs(obj: Any, instance_vars: bool = True) -> dict[str, Any]:
     :param obj: 속성을 가져올 클래스 또는 인스턴스 객체.
     :param instance_vars: True일 경우 인스턴스 변수도 포함합니다. obj가 클래스일 경우 이 값은 무시됩니다.
 
-    :returns: dict[str, Any]: 필터링된 속성 딕셔너리.
+    :returns: 필터링된 속성 딕셔너리.
     """
     # 1. 대상이 클래스인지 인스턴스인지 확인하여 기준 클래스를 정합니다.
     cls = obj if inspect.isclass(obj) else type(obj)
