@@ -330,7 +330,20 @@ class YmlRenderer:
         finally:
             self.data = original_data  # with 블록이 끝나면 (성공하든 실패하든) 실행됩니다.
 
-    def render(self, name: str, temp_data: dict = None):
+    def render(self, key_path: str, temp_data: dict = None):
         with self._temporary_data(temp_data):
-            rendering = self._render(deep_get(self.yml_cache, name, {}))
+            rendering = self._render(deep_get(self.yml_cache, key_path, {}))
         return rendering
+
+    def random_render(self, key_path, temp_data: dict = None):
+        """
+        YAML 데이터를 렌더링하고, 결과 타입에 따라 무작위 요소를 반환합니다.
+        """
+        rendering = self.render(key_path, temp_data=temp_data)
+
+        match rendering:
+            case dict() as d:
+                key = random.choice(list(d.keys()))
+                return {key: d.get(key)}
+            case list() | tuple() as seq:
+                return random.choice(seq)
